@@ -2,7 +2,7 @@ package XML::CompileX::Schema::Loader;
 
 use Modern::Perl '2010';    ## no critic (Modules::ProhibitUseQuotedVersion)
 
-our $VERSION = '0.004';     # VERSION
+our $VERSION = '0.005';     # VERSION
 use utf8;
 use Moo;
 use MooX::Types::MooseLike::Base qw(ArrayRef HashRef InstanceOf);
@@ -124,7 +124,7 @@ XML::CompileX::Schema::Loader - Load a web service and its dependencies for XML:
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -171,6 +171,10 @@ files as warned above.  You can also provide a caching layer, as with
 L<WWW::Mechanize::Cached|WWW::Mechanize::Cached> which is a sub-class of
 L<WWW::Mechanize|WWW::Mechanize> and L<LWP::UserAgent|LWP::UserAgent>.
 
+Please see the distribution's F<eg> directory for sample scripts that use
+this module to save schemas from a URL to the filesystem and then reload them
+again.
+
 =head1 ATTRIBUTES
 
 =head2 wsdl
@@ -305,7 +309,7 @@ from your repository :)
 
 L<https://github.com/mjgardner/xml-compilex-schema-loader>
 
-  https://github.com/mjgardner/xml-compilex-schema-loader.git
+  git clone git://github.com/mjgardner/xml-compilex-schema-loader.git
 
 =head1 AUTHOR
 
